/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'format', 'hu', {
	label: 'Formátum',
	panelTitle: 'Formátum',
	tag_address: 'Címsor',
	tag_div: 'Bekezdés (DIV)',
	tag_h1: 'Fejléc 1',
	tag_h2: 'Fejléc 2',
	tag_h3: 'Fejléc 3',
	tag_h4: 'Fejléc 4',
	tag_h5: 'Fejléc 5',
	tag_h6: 'Fejléc 6',
	tag_p: 'Normál',
	tag_pre: 'Formázott'
} );
