/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'fakeobjects', 'id', {
	anchor: 'Anchor', // MISSING
	flash: 'Animasi Flash',
	hiddenfield: 'Kolom Tersembunyi',
	iframe: 'IFrame',
	unknown: 'Obyek Tak Dikenal'
} );
