/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'fakeobjects', 'ku', {
	anchor: 'لەنگەر',
	flash: 'فلاش',
	hiddenfield: 'شاردنەوەی خانه',
	iframe: 'لەچوارچێوە',
	unknown: 'بەرکارێکی نەناسراو'
} );
