/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'elementspath', 'el', {
	eleLabel: 'Διαδρομή Στοιχείων',
	eleTitle: 'Στοιχείο %1'
} );
