/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'stylescombo', 'sk', {
	label: 'Štýly',
	panelTitle: 'Formátovanie štýlov',
	panelTitle1: 'Štýly bloku',
	panelTitle2: 'Vnútroriadkové (inline) štýly',
	panelTitle3: 'Štýly objeku'
} );
