/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'basicstyles', 'lt', {
	bold: 'Pusjuodis',
	italic: 'Kursyvas',
	strike: 'Perbrauktas',
	subscript: 'Apatinis indeksas',
	superscript: 'Viršutinis indeksas',
	underline: 'Pabrauktas'
} );
