/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'basicstyles', 'is', {
	bold: 'Feitletrað',
	italic: 'Skáletrað',
	strike: 'Yfirstrikað',
	subscript: 'Niðurskrifað',
	superscript: 'Uppskrifað',
	underline: 'Undirstrikað'
} );
