/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'basicstyles', 'pt-br', {
	bold: 'Negrito',
	italic: 'Itálico',
	strike: 'Tachado',
	subscript: 'Subscrito',
	superscript: 'Sobrescrito',
	underline: 'Sublinhado'
} );
