/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'basicstyles', 'vi', {
	bold: 'Đậm',
	italic: 'Nghiêng',
	strike: 'Gạch xuyên ngang',
	subscript: 'Chỉ số dưới',
	superscript: 'Chỉ số trên',
	underline: 'Gạch chân'
} );
