/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'fakeobjects', 'eo', {
	anchor: 'Ankro',
	flash: 'FlaŝAnimacio',
	hiddenfield: 'Kaŝita kampo',
	iframe: 'Enlinia Kadro (IFrame)',
	unknown: 'Nekonata objekto'
} );
