/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'basicstyles', 'et', {
	bold: 'Paks',
	italic: 'Kursiiv',
	strike: 'Läbijoonitud',
	subscript: 'Allindeks',
	superscript: 'Ülaindeks',
	underline: 'Allajoonitud'
} );
