/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'basicstyles', 'de', {
	bold: 'Fett',
	italic: 'Kursiv',
	strike: 'Durchgestrichen',
	subscript: 'Tiefgestellt',
	superscript: 'Hochgestellt',
	underline: 'Unterstrichen'
} );
