/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'format', 'lt', {
	label: 'Šrifto formatas',
	panelTitle: 'Šrifto formatas',
	tag_address: 'Kreipinio',
	tag_div: 'Normalus (DIV)',
	tag_h1: 'Antraštinis 1',
	tag_h2: 'Antraštinis 2',
	tag_h3: 'Antraštinis 3',
	tag_h4: 'Antraštinis 4',
	tag_h5: 'Antraštinis 5',
	tag_h6: 'Antraštinis 6',
	tag_p: 'Normalus',
	tag_pre: 'Formuotas'
} );
