/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'basicstyles', 'pl', {
	bold: 'Pogrubienie',
	italic: 'Kursywa',
	strike: 'Przekreślenie',
	subscript: 'Indeks dolny',
	superscript: 'Indeks górny',
	underline: 'Podkreślenie'
} );
