/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'format', 'sr-latn', {
	label: 'Format',
	panelTitle: 'Format',
	tag_address: 'Adresa',
	tag_div: 'Normalno (DIV)',
	tag_h1: 'Naslov 1',
	tag_h2: 'Naslov 2',
	tag_h3: 'Naslov 3',
	tag_h4: 'Naslov 4',
	tag_h5: 'Naslov 5',
	tag_h6: 'Naslov 6',
	tag_p: 'Normal',
	tag_pre: 'Formatirano'
} );
